@@ -6,16 +6,41 @@ from flask import Flask, send_file
 from flask_collect import Collect
 from flask_cors import CORS
 from flask_jwt_extended import JWTManager
-from flask_security import PeeweeUserDatastore, Security
+from flask_security import Security
 from freenit.schemas.paging import PageOutSchema
 
 from . import cli
 from .api import create_api
-from .db import db
 from .utils import sendmail
 
 
-def create_app(config, app=None, schemas={}):
+def sqlinit(app):
+    from flask_security import PeeweeUserDatastore
+    from .db import db
+    db.init_app(app)
+    app.db = db
+    User = import_module(f"{app.config['NAME']}.models.sql.user").User
+    role_module = import_module(f"{app.config['NAME']}.models.sql.role")
+    Role = role_module.Role
+    UserRoles = role_module.UserRoles
+    app.user_datastore = PeeweeUserDatastore(
+        app.db,
+        User,
+        Role,
+        UserRoles,
+    )
+
+
+def mongoinit(app):
+    from flask_security import MongoEngineUserDatastore
+    from flask_mongoengine import MongoEngine
+    app.db = MongoEngine(app)
+    User = import_module(f"{app.config['NAME']}.models.mongo.user").User
+    Role = import_module(f"{app.config['NAME']}.models.mongo.role").Role
+    app.user_datastore = MongoEngineUserDatastore(app.db, User, Role)
+
+
+def create_app(config, app=None, schemas={}, dbtype='sql'):
     if app is None:
         app = Flask(__name__)
         app.config.from_object(config)
@@ -29,23 +54,13 @@ def create_app(config, app=None, schemas={}):
             return 'No such file', 404
 
     app.sendmail = lambda message: sendmail(app.config, message)
-
     app.collect = Collect(app)
-    db.init_app(app)
-    app.db = db
-
-    User = import_module(f"{config.NAME}.models.user").User
-    role_module = import_module(f"{config.NAME}.models.role")
-    Role = role_module.Role
-    UserRoles = role_module.UserRoles
-
-    app.user_datastore = PeeweeUserDatastore(
-        app.db,
-        User,
-        Role,
-        UserRoles,
-    )
-
+    app.dbtype = dbtype
+    if dbtype == 'sql':
+        sqlinit(app)
+    elif dbtype == 'mongo':
+        mongoinit(app)
+    app.security = Security(app, app.user_datastore)
     user_module = schemas.get('user', None)
     if user_module is None:
 
@@ -55,7 +70,6 @@ def create_app(config, app=None, schemas={}):
         UserSchema = import_module(user_module).UserSchema
     setattr(freenit.schemas.user, 'UserSchema', UserSchema)
     PageOutSchema(UserSchema, sys.modules['freenit.schemas.user'])
-
     role_module = schemas.get('role', None)
     if role_module is None:
 
@@ -65,8 +79,6 @@ def create_app(config, app=None, schemas={}):
         RoleSchema = import_module(role_module).RoleSchema
     setattr(freenit.schemas.role, 'RoleSchema', RoleSchema)
     PageOutSchema(RoleSchema, sys.modules['freenit.schemas.role'])
-
-    app.security = Security(app, app.user_datastore)
     app.jwt = JWTManager(app)
     create_api(app)
     app.cors = CORS(app, supports_credentials=True)
